==> safecheck-3.0.72.jar: filiale/qbjyangchun/sqls/getCheckPlanAreaList.sql <==
select
 count(*) f_plan_total,
 sum(f_weijian) f_weijian,
 sum(f_yijian) f_yijian,
 sum(f_ruhu) f_ruhu,
 sum(f_buyu) f_buyu,
 sum(f_jujian) f_jujian,
 sum(f_chaichu) f_chaichu,
 sum(f_tingyong) f_tingyong,
 sum(f_weitongqi) f_weitongqi,
 sum(f_defectsum) f_defectsum,
 {entity.findDialect()==$SqlServer$:$cast(CONVERT(decimal(18,2),case when count(*)=0 then 0.00 else sum(f_yijian)/(count(*)+0.00)*100.00 end)  as varchar)+'%'$, $to_char(to_number(case when count(*)=0 then 0.00 else sum(f_yijian)/(count(0)+0.00)*100.00 end)) || '%'$} f_check_bv,
 {groupName}
from(
	select
		cpi.f_no_checkplan,
		cpi.f_residential_area,
		cpi.f_plan_id,
		cpl.f_plan_name,
        cpall.f_offsite_time,
        cpi.f_user_type,
		cpi.f_filialeid,
		cpl.f_plan_year as f_year,
		cpl.f_plan_month as f_month,
		{entity.findDialect()==$SqlServer$:$cast(cpl.f_plan_year as varchar)+'年'+cast(cpl.f_plan_month as varchar)+'月'$, $	CONCAT(CONCAT(cpl.f_plan_year,'年'),CONCAT(cpl.f_plan_month,'月'))$} f_plan_month,
		case when cpall.f_checker_name is null then cpl.f_checker else cpall.f_checker_name end f_checker_name,
        case when cpall.f_checker_id is null then cpl.f_checker_id else cpall.f_checker_id end f_checker_id,
		case when cpi.f_state='未检' then 1 else 0 end f_weijian,
		case when cpi.f_state='已检' then 1 else 0 end f_yijian,
		case when f_entry_status='入户' then 1 else 0 end f_ruhu,
		case when f_entry_status='到访不遇' then 1 else 0 end f_buyu,
		case when f_entry_status='拒检' then 1 else 0 end f_jujian,
		case when f_entry_status='拆除' then 1 else 0 end f_chaichu,
		case when f_entry_status='停用' then 1 else 0 end f_tingyong,
		case when f_entry_status='未通气' then 1 else 0 end f_weitongqi,
    case when f_defect_content like '%有隐患%' and f_entry_status='入户' then 1 else 0 end f_defectsum
	from
        t_check_plan_item cpi
	left join t_check_plan cpl on cpi.f_plan_id = cpl.id
	left join
	(select
		f_check_item_id,max(f_offsite_time) f_offsite_time
	from t_check_paper
	group by f_check_item_id) cp on cpi.id=cp.f_check_item_id
	left join t_check_paper cpall on cp.f_check_item_id = cpall.f_check_item_id and cp.f_offsite_time = cpall.f_offsite_time
	where cpi.f_state!='作废'
) ch left join (
 select ua.f_residential_area area,count(*) f_user_number
 from t_user_address ua
 left join t_userinfo u on ua.f_userinfo_id=u.f_userinfo_id
 where f_user_state='正常'
 group by ua.f_residential_area
) u on ch.f_residential_area = u.area
left join(
    select  f_department_name  department,id  from    t_user
    )dep on  ch.f_checker_id = dep.id
where {condition}
group by
{groupName}
 order by {groupName}

==> safecheck-3.1.66.jar: filiale/qbjyangchun/sqls/getCheckPlanAreaList.sql <==
select
 count(*) f_plan_total,
 sum(f_weijian) f_weishangmen,
 sum(f_weijian) + sum(f_jujian) + sum(f_buyu) + sum(f_buyu2)+sum(f_buyu3) + sum(f_buyu4) f_weijian,
 sum(f_yijian) f_yishangmen,
 sum(f_ruhu)+ sum(f_chaichu) + sum(f_tingyong) + sum(f_weitongqi) f_yijian,
 sum(f_ruhu)+ sum(f_chaichu) + sum(f_tingyong) + sum(f_weitongqi) +  sum(f_jujian) + sum(f_buyu3) + sum(f_buyu4) f_yiwancheng,
 sum(f_ruhu) f_ruhu,
 sum(f_buyu) f_buyu,
 sum(f_buyu2) f_buyu2,
 sum(f_buyu3) f_buyu3,
 sum(f_buyu4) f_buyu4,
 sum(f_jujian) f_jujian,
 sum(f_chaichu) f_chaichu,
 sum(f_tingyong) f_tingyong,
 sum(f_weitongqi) f_weitongqi,
 sum(f_defectsum) f_defectsum,
 cast(CONVERT(decimal(18,2),case when count(*)=0 then 0.00 else sum(f_yijian)/(count(*)+0.00)*100.00 end)  as varchar)+'%' f_shangmen_bv,
 cast(CONVERT(decimal(18,2),case when count(*)=0 then 0.00 else sum(f_ruhu)/(count(*)+0.00)*100.00 end)  as varchar)+'%' f_check_bv,
 cast(CONVERT(decimal(18,2),case when count(*)=0 then 0.00 else (sum(f_ruhu)+ sum(f_chaichu) + sum(f_tingyong) + sum(f_weitongqi) +  sum(f_jujian) + sum(f_buyu3) + sum(f_buyu4))/(count(*)+0.00)*100.00 end)  as varchar)+'%' f_wangcheng_bv,
 {groupName}
from(
	select
		cpi.f_no_checkplan,
		cpi.f_residential_area,
		cpi.f_plan_id,
		cpl.f_plan_name,
        cpall.f_offsite_time,
        cpi.f_user_type,
		cpi.f_filialeid,
		cpl.f_plan_year as f_year,
		cpl.f_plan_month as f_month,
		{entity.findDialect()==$SqlServer$:$cast(cpl.f_plan_year as varchar)+'年'+cast(cpl.f_plan_month as varchar)+'月'$, $	CONCAT(CONCAT(cpl.f_plan_year,'年'),CONCAT(cpl.f_plan_month,'月'))$} f_plan_month,
		case when cpall.f_checker_name is null then cpl.f_checker else cpall.f_checker_name end f_checker_name,
        case when cpall.f_checker_id is null then cpl.f_checker_id else cpall.f_checker_id end f_checker_id,
		case when cpi.f_state='未检' then 1 else 0 end f_weijian,
		case when cpi.f_state='已检' then 1 else 0 end f_yijian,
		case when f_entry_status='入户' then 1 else 0 end f_ruhu,
		case when f_entry_status='到访不遇' and cpall.f_check_version = 1 then 1 else 0 end f_buyu,
		case when f_entry_status='到访不遇' and cpall.f_check_version = 2 then 1 else 0 end f_buyu2,
		case when f_entry_status='到访不遇' and cpall.f_check_version = 3 then 1 else 0 end f_buyu3,
		case when f_entry_status='到访不遇' and cpall.f_check_version > 3 then 1 else 0 end f_buyu4,
		case when f_entry_status='拒检' then 1 else 0 end f_jujian,
		case when f_entry_status='拆除' then 1 else 0 end f_chaichu,
		case when f_entry_status='停用' then 1 else 0 end f_tingyong,
		case when f_entry_status='未通气' then 1 else 0 end f_weitongqi,
    case when f_defect_content like '%有隐患%' and f_entry_status='入户' then 1 else 0 end f_defectsum
	from
        t_check_plan_item cpi
	left join t_check_plan cpl on cpi.f_plan_id = cpl.id
	left join
	(select
		f_check_item_id,max(f_offsite_time) f_offsite_time
	from t_check_paper
	group by f_check_item_id) cp on cpi.id=cp.f_check_item_id
	left join t_check_paper cpall on cp.f_check_item_id = cpall.f_check_item_id and cp.f_offsite_time = cpall.f_offsite_time
	where cpi.f_state!='作废'
) ch left join (
 select ua.f_residential_area area,count(*) f_user_number
 from t_user_address ua
 left join t_userinfo u on ua.f_userinfo_id=u.f_userinfo_id
 where f_user_state='正常'
 group by ua.f_residential_area
) u on ch.f_residential_area = u.area
left join(
    select  f_department_name  department,id  from    t_user
    )dep on  ch.f_checker_id = dep.id
where {condition}
group by
{groupName}
 order by {groupName}
